import logging
from normality import collapse_spaces, stringify

from fingerprints.constants import BRACKETED, WS
from fingerprints.replacers import replace_types
from fingerprints.text import clean_strict
from fingerprints.prefix import remove_person_prefix

log = logging.getLogger(__name__)


def generate(text, keep_order=False):
    text = stringify(text)
    if text is None:
        return

    # this needs to happen before the replacements
    text = text.lower()
    text = remove_person_prefix(text)

    # remove any text in brackets
    text = BRACKETED.sub(WS, text)

    # super hard-core string scrubbing
    text = clean_strict(text)
    text = replace_types(text)

    if keep_order:
        text = collapse_spaces(text)
    else:
        # final manicure, based on openrefine algo
        parts = [p for p in text.split(WS) if len(p)]
        text = WS.join(sorted(set(parts)))

    if not len(text):
        return None

    return text



import re
import logging
from normality import collapse_spaces, ascii_text, category_replace

from fingerprints.constants import WS

log = logging.getLogger(__name__)
CHARACTERS_REMOVE_RE = re.compile(r'[\.\']')


def clean_strict(text, boundary=WS):
    """Super-hardcore string scrubbing."""
    # transliterate to ascii
    text = ascii_text(text)
    # replace punctuation and symbols
    text = CHARACTERS_REMOVE_RE.sub('', text)
    text = category_replace(text)
    # pad out for company type replacements
    text = ''.join((boundary, collapse_spaces(text), boundary))
    return text



# coding: utf-8
from unittest import TestCase

import fingerprints

fp = fingerprints.generate


class FingerprintsTest(TestCase):

    def test_normal_names(self):
        self.assertEqual(fp('Mr. Boaty McBoatface'), 'boaty mcboatface')
        self.assertEqual(fp('Open S.A.R.L.'), 'open sarl')
        self.assertEqual(fp("Johnson's Coffee Shop"), 'coffee johnsons shop')
        self.assertEqual(fp('New York, New York'), 'new york')

    def test_replacers(self):
        self.assertEqual(fp('Foo Limited'), 'foo ltd')
        self.assertEqual(fp('Foo International bla Limited'), 'bla foo intl ltd')  # noqa
        self.assertEqual(fp('Foo International Limited'), 'foo intl ltd')

    def test_cyrillic(self):
        self.assertEqual(fp(u'РАДИК ІВАН ЛЬВОВИЧ'), 'ivan lvovic radik')
        self.assertEqual(fp(u'КУШНАРЬОВ ДМИТРО ВІТАЛІЙОВИЧ'), 'dmitro kusnarov vitalijovic')  # noqa
        self.assertEqual(fp(u'Порошенко Петро Олексійович'), 'oleksijovic petro porosenko')  # noqa

    def test_turcic(self):
        self.assertEqual(fp(u'FUAD ALIYEV ƏHMƏD OĞLU'),
                         'ahmad aliyev fuad oglu')

    def test_german(self):
        self.assertEqual(fp(u'Siemens Aktiengesellschaft'), 'ag siemens')  # noqa
        self.assertEqual(fp(u'Software und- Systemgesellschaft mit beschr Haftung'),  # noqa
                         'gmbh software systemgesellschaft und')  # noqa

    def test_company(self):
        self.assertEqual(fp('S.R.L. "Magic-Arrow" ICS'), 'arrow ics magic srl')  # noqa

    def test_brackets(self):
        self.assertEqual(fp(u'Foo (Bar) CORPORATION'), 'corp foo')  # noqa
